
//
// Define a common event class for all business entity events
//
public class EntityEventArgs : EventArgs
{
	// Define event members, to provide information about the event
}

//
// Define a delegate specifying the signature for business entity-related events
//
public delegate void EntityEventHandler(Object source, EntityEventArgs e);

//
// Define a custom Entity class that raises events when the business entity state changes
//
public class OrderEntity
{
	//
	// Define 'before' and 'after' events for business entity state changes
	//
	public event EntityEventHandler BeforeChange, AfterChange;

	//
	// Private fields, to hold the business entity's state
	//
	private int orderID;
	private int customerID;
	private DateTime orderDate;
	private DateTime shippedDate;
	private DataSet orderDetails;

	//
	// Public properties, to expose the business entity's state
	//
	public int OrderID
	{
		get { return orderID; }
		set
		{
			BeforeChange(this, new EntityEventArgs()); // Raise a 'before' event
			orderID = value;
			AfterChange(this, new EntityEventArgs()); // Raise an 'after' event
		}
	}

	public int CustomerID
	{
		get { return customerID; }
		set
		{
			BeforeChange(this, new EntityEventArgs()); // Raise a 'before' event
			customerID = value;
			AfterChange(this, new EntityEventArgs()); // Raise an 'after' event
		}
	}
	
	public DateTime OrderDate
	{
		get { return orderDate; }
		set
		{
			BeforeChange(this, new EntityEventArgs()); // Raise a 'before' event
			orderDate = value;
			AfterChange(this, new EntityEventArgs()); // Raise an 'after' event
		}
	}
	
	public DateTime ShippedDate
	{
		get { return shippedDate; }
		set
		{
			BeforeChange(this, new EntityEventArgs()); // Raise a 'before' event
			shippedDate = value;
			AfterChange(this, new EntityEventArgs()); // Raise an 'after' event
		}
	}
	// Additional members, as required ...
}
